@@ -13,6 +13,7 @@ module Propellor.Property.Systemd (
 	networkd,
 	journald,
 	logind,
+	escapePath,
 	-- * Configuration
 	installed,
 	Option,
@@ -58,7 +59,9 @@ import Utility.FileMode
 import Utility.Split
 
 import Data.List
+import Data.Char
 import qualified Data.Map as M
+import Text.Printf
 
 type ServiceName = String
 
@@ -201,13 +204,18 @@ killUserProcesses = set "yes" <!> set "no"
 
 -- | Ensures machined and machinectl are installed
 machined :: Property Linux
-machined = withOS "machined installed" $ \w o ->
-	case o of
-		-- Split into separate debian package since systemd 225.
-		(Just (System (Debian _ suite) _))
-			| not (isStable suite) || suite == (Stable "stretch") ->
-				ensureProperty w $ Apt.installed ["systemd-container"]
-		_ -> noChange
+machined = installeddebian `pickOS` assumeinstalled
+  where
+	installeddebian :: Property DebianLike
+	installeddebian = withOS "machined installed" $ \w o ->
+		case o of
+			-- Split into separate debian package since systemd 225.
+			(Just (System (Debian _ suite) _))
+				| not (isStable suite) || suite == (Stable "stretch") ->
+					ensureProperty w $ Apt.installed ["systemd-container"]
+			_ -> noChange
+	assumeinstalled :: Property Linux
+	assumeinstalled = doNothing
 
 -- | Defines a container with a given machine name,
 -- and how to create its chroot if not already present.
@@ -459,3 +467,15 @@ bind p = containerCfg $ "--bind=" ++ toBind p
 -- | Read-only mind mount.
 bindRo :: Bindable p => p -> RevertableProperty (HasInfo + Linux) (HasInfo + Linux)
 bindRo p = containerCfg $ "--bind-ro=" ++ toBind p
+
+-- | Escapes a path for inclusion in a systemd unit name,
+-- the same as systemd-escape does.
+escapePath :: FilePath -> String
+escapePath = concatMap escape 
+	. dropWhile (== '/')
+	. reverse . dropWhile (== '/') . reverse
+  where
+	escape '/' = "-"
+	escape c
+		| ((isAscii c && isAlphaNum c) || c == '_') = [c]
+		| otherwise = '\\' : 'x' : printf "%x" c
